```
Usage: vcd vapp connect [OPTIONS] <vapp-name> <orgvdc-network-name>

Options:
  --retain-ip    True if the network resources such as IP/MAC of router will
                 be retained across deployments. False by default
  --is-deployed  True if this orgvdc network has been deployed. False by
                 default
  -h, --help     Show this message and exit.

```
